.. _plugins-index:

Plugin Documentation
====================

The links below are for plugin-specific docs. Please see the :ref:`plugin guide
<plugin_system>` for details on developing and using plugins.

.. toctree::
   :maxdepth: 2

   sge
   users
   ipython
   boto
   tmux
   condor
   hadoop
   mpich2
   mysqlcluster
   pkginstaller
   pypkginstaller
   xvfb
